@@ -8,16 +8,23 @@
 # @License: BSD 3-Clause
 # @Copyright: Brian Cherinka
 
-import os
-import shutil
-
-from invoke import Collection, task
-
-
 # This file contains tasks that can be easily run from the shell terminal using the
 # Invoke python package. If you do not have invoke, install it with pip install
 # To list the tasks available, type invoke --list from the top-level repo directory
 
+import inspect
+import os
+import shutil
+
+
+# Monkeypatching needed for invoke to work in Python 3.10 and 3.11 for now.
+# See https://github.com/pyinvoke/invoke/issues/833#issuecomment-1293148106
+if not hasattr(inspect, "getargspec"):
+    inspect.getargspec = inspect.getfullargspec  # type: ignore
+
+
+from invoke import Collection, task  # isort: skip
+
 
 @task
 def clean_docs(ctx, target=None):
